@@ -55,8 +55,8 @@ select
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_adr.CPOSTAL ELSE c_cli.CPOSTAL END CPOSTAL,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_poble.POBLE ELSE c_cli_poble.POBLE END POBLE,
     CASE WHEN c_cli.COMANDA_ID IS NULL THEN cd_comu.PAIS_CODI ELSE c_cli_comu.PAIS_CODI END CODI_PAIS,
-    CASE WHEN c_cli.COMANDA_ID IS NULL THEN NULL ELSE c_cli.TELEFON END TELEFON,
-    CASE WHEN c_cli.COMANDA_ID IS NULL THEN NULL ELSE c_cli.EMAIL END MAIL,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN c_con.telefon ELSE c_cli.TELEFON END TELEFON,
+    CASE WHEN c_cli.COMANDA_ID IS NULL THEN c_con.email ELSE c_cli.EMAIL END MAIL,
     cd.PES_NET, cd.PES_BRUT,
     c.obs_comanda,
     cd.obs_distribucio
@@ -71,6 +71,7 @@ join comunitats cd_comu on cd_prov.COMUNITAT_ID = cd_comu.ID
 
 join tercers cd_ter on cd.TERCER_ID = cd_ter.ID
 join clients cd_cli on cd_ter.ID = cd_cli.TERCER_ID and c.EMPRESA_ID = cd_cli.EMPRESA_ID    
+left join select_contactes_tercer(cd_ter.id) c_con on c_con.tercer_id = cd_ter.id
 left join comandes_client c_cli on c.ID = c_cli.COMANDA_ID
 left join pobles c_cli_poble on c_cli.POBLE_ID = c_cli_poble.ID
 left join comarques c_cli_coma on c_cli_poble.COMARCA_ID = c_cli_coma.ID
